4Insight Campaigns for Python
=============================

``fourinsight.campaigns`` is a high-level package for conviniently and securely accessing **Campaigns** in `4insight.io`_.

.. _4Insight.io: https://4insight.io